@@ -7,22 +7,25 @@ This package contains all objects managing Tunneling and Routing Connections..
 - Tunnel uses UDP packets and builds a static tunnel with KNX/IP device.
 """
 # flake8: noqa
-from .connection import ConnectionConfig, ConnectionType
+from .connection import ConnectionConfig, ConnectionType, SecureConfig
 from .const import DEFAULT_MCAST_GRP, DEFAULT_MCAST_PORT
 from .gateway_scanner import GatewayDescriptor, GatewayScanFilter, GatewayScanner
 from .knxip_interface import KNXIPInterface, knx_interface_factory
 from .routing import Routing
+from .self_description import DescriptionQuery
 from .tunnel import TCPTunnel, UDPTunnel
 
 __all__ = [
     "DEFAULT_MCAST_GRP",
     "DEFAULT_MCAST_PORT",
+    "DescriptionQuery",
     "GatewayScanFilter",
     "GatewayScanner",
     "ConnectionConfig",
+    "SecureConfig",
     "ConnectionType",
     "KNXIPInterface",
-    "TCPTunnel",
     "Routing",
+    "TCPTunnel",
     "UDPTunnel",
 ]
