@@ -3,7 +3,9 @@ from __future__ import annotations
 
 from enum import Enum, auto
 
-from .const import DEFAULT_MCAST_PORT
+from xknx.telegram.address import IndividualAddress, IndividualAddressableType
+
+from .const import DEFAULT_MCAST_GRP, DEFAULT_MCAST_PORT
 from .gateway_scanner import GatewayScanFilter
 
 
@@ -28,12 +30,17 @@ class ConnectionConfig:
         * ROUTING use KNX/IP multicast routing.
         * TUNNELING connect to a specific KNX/IP tunneling device via UDP.
         * TUNNELING_TCP connect to a specific KNX/IP tunneling v2 device via TCP.
+    * individual address:
+        * ROUTING the individual address used as source address for routing
+        * SECURE TUNNELING use a specific tunnel endpoint from the knxkeys file
     * local_ip: Local ip of the interface though which KNXIPInterface should connect.
     * gateway_ip: IP of KNX/IP tunneling device.
     * gateway_port: Port of KNX/IP tunneling device.
     * route_back: For TUNNELING connection.
         The KNXnet/IP Server shall use the IP address and port in the received IP package
         as the target IP address or port number for the response to the KNXnet/IP Client.
+    * multicast_group: Multicast group for KNXnet/IP routing.
+    * multicast_port: Multicast port for KNXnet/IP routing.
     * auto_reconnect: Auto reconnect to KNX/IP tunneling device if connection cannot be established.
     * auto_reconnect_wait: Wait n seconds before trying to reconnect to KNX/IP tunneling device.
     * scan_filter: For AUTOMATIC connection, limit scan with the given filter
@@ -45,27 +52,35 @@ class ConnectionConfig:
         self,
         *,
         connection_type: ConnectionType = ConnectionType.AUTOMATIC,
+        individual_address: IndividualAddressableType | None = None,
         local_ip: str | None = None,
         local_port: int = 0,
         gateway_ip: str | None = None,
         gateway_port: int = DEFAULT_MCAST_PORT,
         route_back: bool = False,
+        multicast_group: str = DEFAULT_MCAST_GRP,
+        multicast_port: int = DEFAULT_MCAST_PORT,
         auto_reconnect: bool = True,
         auto_reconnect_wait: int = 3,
-        scan_filter: GatewayScanFilter = GatewayScanFilter(),
+        scan_filter: GatewayScanFilter | None = None,
         threaded: bool = False,
         secure_config: SecureConfig | None = None,
     ):
         """Initialize ConnectionConfig class."""
         self.connection_type = connection_type
+        self.individual_address = (
+            IndividualAddress(individual_address) if individual_address else None
+        )
         self.local_ip = local_ip
         self.local_port = local_port
         self.gateway_ip = gateway_ip
         self.gateway_port = gateway_port
         self.route_back = route_back
+        self.multicast_group = multicast_group
+        self.multicast_port = multicast_port
         self.auto_reconnect = auto_reconnect
         self.auto_reconnect_wait = auto_reconnect_wait
-        self.scan_filter = scan_filter
+        self.scan_filter = scan_filter or GatewayScanFilter()
         self.threaded = threaded
         self.secure_config = secure_config
 
