@@ -24,8 +24,9 @@ from xknx.knxip import (
     RoutingIndication,
     RoutingLostMessage,
 )
-from xknx.telegram import Telegram, TelegramDirection
+from xknx.telegram import IndividualAddress, Telegram, TelegramDirection
 
+from .const import DEFAULT_INDIVIDUAL_ADDRESS, DEFAULT_MCAST_GRP, DEFAULT_MCAST_PORT
 from .interface import Interface, TelegramCallbackType
 from .ip_secure import SecureGroup
 from .transport import KNXIPTransport, UDPTransport
@@ -137,13 +138,19 @@ class Routing(Interface):
     def __init__(
         self,
         xknx: XKNX,
+        individual_address: IndividualAddress | None,
         telegram_received_callback: TelegramCallbackType,
         local_ip: str,
+        multicast_group: str = DEFAULT_MCAST_GRP,
+        multicast_port: int = DEFAULT_MCAST_PORT,
     ):
         """Initialize Routing class."""
         self.xknx = xknx
+        self.individual_address = individual_address or DEFAULT_INDIVIDUAL_ADDRESS
         self.telegram_received_callback = telegram_received_callback
         self.local_ip = local_ip
+        self.multicast_group = multicast_group
+        self.multicast_port = multicast_port
 
         self._init_transport()
         self.transport.register_callback(
@@ -160,7 +167,7 @@ class Routing(Interface):
         """Initialize transport."""
         self.transport = UDPTransport(
             local_addr=(self.local_ip, 0),
-            remote_addr=(self.xknx.multicast_group, self.xknx.multicast_port),
+            remote_addr=(self.multicast_group, self.multicast_port),
             multicast=True,
         )
 
@@ -172,6 +179,7 @@ class Routing(Interface):
 
     async def connect(self) -> bool:
         """Start routing."""
+        self.xknx.current_address = self.individual_address
         await self.xknx.connection_manager.connection_state_changed(
             XknxConnectionState.CONNECTING
         )
@@ -213,7 +221,7 @@ class Routing(Interface):
         cemi = CEMIFrame.init_from_telegram(
             telegram=telegram,
             code=CEMIMessageCode.L_DATA_IND,
-            src_addr=self.xknx.own_address,
+            src_addr=self.individual_address,
         )
         routing_indication = RoutingIndication(cemi=cemi)
 
@@ -252,7 +260,7 @@ class Routing(Interface):
         if routing_indication.cemi is None:
             # Don't handle invalid cemi frames (None)
             return
-        if routing_indication.cemi.src_addr == self.xknx.own_address:
+        if routing_indication.cemi.src_addr == self.individual_address:
             logger.debug("Ignoring own packet")
             return
 
@@ -277,21 +285,31 @@ class SecureRouting(Routing):
     def __init__(
         self,
         xknx: XKNX,
+        individual_address: IndividualAddress | None,
         telegram_received_callback: TelegramCallbackType,
         local_ip: str,
         backbone_key: bytes,
         latency_ms: int | None = None,
+        multicast_group: str = DEFAULT_MCAST_GRP,
+        multicast_port: int = DEFAULT_MCAST_PORT,
     ):
         """Initialize SecureRouting class."""
         self.backbone_key = backbone_key
         self.latency_ms = latency_ms or DEFAULT_LATENCY_TOLERANCE_MS
-        super().__init__(xknx, telegram_received_callback, local_ip)
+        super().__init__(
+            xknx,
+            individual_address=individual_address,
+            telegram_received_callback=telegram_received_callback,
+            local_ip=local_ip,
+            multicast_group=multicast_group,
+            multicast_port=multicast_port,
+        )
 
     def _init_transport(self) -> None:
         """Initialize transport."""
         self.transport = SecureGroup(
             local_addr=(self.local_ip, 0),
-            remote_addr=(self.xknx.multicast_group, self.xknx.multicast_port),
+            remote_addr=(self.multicast_group, self.multicast_port),
             backbone_key=self.backbone_key,
             latency_ms=self.latency_ms,
         )
