@@ -28,27 +28,30 @@ class CEMIFrame:
         self,
         code: CEMIMessageCode = CEMIMessageCode.L_DATA_IND,
         flags: int = 0,
-        src_addr: IndividualAddress = IndividualAddress(None),
-        dst_addr: GroupAddress | IndividualAddress = GroupAddress(None),
-        tpci: TPCI = TDataGroup(),
+        src_addr: IndividualAddress | None = None,
+        dst_addr: GroupAddress | IndividualAddress | None = None,
+        tpci: TPCI | None = None,
         payload: APCI | None = None,
     ):
         """Initialize CEMIFrame object."""
         self.code = code
         self.flags = flags
-        self.src_addr = src_addr
-        self.dst_addr = dst_addr
-        self.tpci = tpci
+        self.src_addr = src_addr or IndividualAddress(None)
+        self.dst_addr = dst_addr or GroupAddress(None)
+        self.tpci = tpci or TDataGroup()
         self.payload = payload
 
     @staticmethod
     def init_from_telegram(
         telegram: Telegram,
         code: CEMIMessageCode = CEMIMessageCode.L_DATA_IND,
-        src_addr: IndividualAddress = IndividualAddress(None),
+        src_addr: IndividualAddress | None = None,
     ) -> CEMIFrame:
         """Return CEMIFrame from a Telegram."""
-        cemi = CEMIFrame(code=code, src_addr=src_addr)
+        cemi = CEMIFrame(
+            code=code,
+            src_addr=src_addr or IndividualAddress(None),
+        )
         # dst_addr, payload and cmd are set by telegram.setter
         cemi.telegram = telegram
         return cemi
@@ -152,7 +155,9 @@ class CEMIFrame:
 
         npdu_len = cemi[8 + addil]
 
-        apdu = cemi[9 + addil :]
+        tpdu = cemi[9 + addil :]
+        apdu = bytes([tpdu[0] & 0b11]) + tpdu[1:]  # clear TPCI bits
+
         if len(apdu) != (npdu_len + 1):  # TCPI octet not included in NPDU length
             raise CouldNotParseKNXIP(
                 f"APDU LEN should be {npdu_len} but is {len(apdu) - 1} in CEMI: {cemi.hex()}"
@@ -164,12 +169,10 @@ class CEMIFrame:
         # APCI (application layer control information) -> Last  10 bit of TPCI/APCI
         try:
             self.tpci = TPCI.resolve(
-                raw_tpci=cemi[9 + addil], dst_is_group_address=dst_is_group_address
+                raw_tpci=tpdu[0], dst_is_group_address=dst_is_group_address
             )
         except ConversionError as err:
-            raise UnsupportedCEMIMessage(
-                f"TPCI not supported: {cemi[9 + addil]:#10b}"
-            ) from err
+            raise UnsupportedCEMIMessage(f"TPCI not supported: {tpdu[0]:#10b}") from err
 
         if self.tpci.control:
             if npdu_len:
