@@ -53,6 +53,6 @@ class SessionStatus(KNXIPBody):
             )
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return f'<SessionStatus status="{self.status}" />'
